// $Id: PixmapCacheDialog.cpp,v 1.8 2012/01/20 08:17:21 hpereira Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* ANY WARRANTY;  without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.   See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* software; if not, write to the Free Software Foundation, Inc., 59 Temple
* Place, Suite 330, Boston, MA   02111-1307 USA
*
*
*******************************************************************************/
/*!
\file PixmapCacheDialog.cpp
\brief displays PixmapCache names and counts
\author Hugo Pereira
\version $Revision: 1.8 $
\date $Date: 2012/01/20 08:17:21 $
*/

#include "BaseIcons.h"
#include "CustomPixmap.h"
#include "PixmapCacheDialog.h"
#include "PixmapEngine.h"
#include "IconSize.h"
#include "AnimatedTreeView.h"

#include <QtGui/QPushButton>
#include <QtGui/QLayout>

//__________________________________________________________________________
PixmapCacheDialog::PixmapCacheDialog( QWidget* parent ):
CustomDialog( parent, OkButton, Qt::Window )
{

    Debug::Throw( "PixmapCacheDialog::PixmapCacheDialog.\n" );
    setWindowTitle( "Pixmap Cache" );
    setOptionName( "ICON_CACHE_DIALOG" );

    layout()->setMargin(0);
    buttonLayout().setMargin(5);

    // insert main vertical box
    list_ = new AnimatedTreeView( this );
    mainLayout().addWidget( list_ );
    list_->setModel( &model_ );
    list_->setIconSize( IconSize( IconSize::Large ) );

    QPushButton *button;
    buttonLayout().insertWidget( 1, button = new QPushButton( PixmapEngine::get( ICONS::RELOAD ),"&Update", this ) );
    connect( button, SIGNAL( clicked() ), SLOT( update() ) );
    button->setAutoDefault( false );

}

//__________________________________________________________________________
void PixmapCacheDialog::update( void )
{

    Debug::Throw( "PixmapCacheDialog::update.\n" );

    // retrieve cache
    const PixmapEngine::Cache& cache( PixmapEngine::cache() );
    model_.set( PixmapCacheModel::List( cache.begin(), cache.end() ) );

    list_->resizeColumnToContents( PixmapCacheModel::ICON );

}
