
// $Id: AlienCommand.cpp,v 1.1 2012/01/20 08:16:59 hpereira Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* software; if not, write to the Free Software Foundation, Inc., 59 Temple
* Place, Suite 330, Boston, MA  02111-1307 USA
*
*
*******************************************************************************/

/*!
\file    AlienCommand.cpp
\brief   handles Top commands
\author  Hugo Pereira
\version $Revision: 1.1 $
\date    $Date: 2012/01/20 08:16:59 $
*/

#include "AlienCommand.h"

//___________________________________________________________________
unsigned int& AlienCommand::_counter( void )
{
    static unsigned int counter( 0 );
    return counter;
}

//___________________________________________________________________
AlienCommand::AlienCommand( const Type type ):
    Counter( "AlienCommand" ),
    id_( _counter()++ ),
    priority_( 0 ),
    type_( type )
{}

//___________________________________________________________________
QString AlienCommand::name( const Type& type )
{
    Debug::Throw( "AlienCommand::name.\n" );

    if( _names().empty() ) _initializeNames();
    NameMap::const_iterator iter( _names().find( type ) );
    return iter != _names().end() ? iter->second:"";
}

//___________________________________________________________________
void AlienCommand::_initializeNames( void )
{
    Debug::Throw( "AlienCommand::_initializeNames.\n" );

    _names()[NONE] = "none";
    _names()[JOB_LIST]="query job list";
    _names()[USER_LIST]="query user list";
    _names()[DEFAULT_USER]="query default user name";
    _names()[RESUBMIT]="resubmit selected job(s)";
    _names()[TRACE]="query job information";
    _names()[TRACE_JDL]="query job JDL";
    _names()[TRACE_ALL]="query job information";
    _names()[JOB_FILES]="query job output files";

    _names()[COPY]="copy selected remote file";

    _names()[KILL]="kill selected job(s)";
    _names()[RESUBMIT_MASTER]="resubmit selected job(s)";
    _names()[KILL_MASTER]="kill selected master job(s)";
}

//___________________________________________________________________
AlienCommand::NameMap& AlienCommand::_names( void )
{
    static NameMap names;
    return names;
}
