
// $Id: AlienCommandDialog.cpp,v 1.1 2012/01/20 08:16:59 hpereira Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* software; if not, write to the Free Software Foundation, Inc., 59 Temple
* Place, Suite 330, Boston, MA  02111-1307 USA
*
*
*******************************************************************************/

/*!
\file AlienCommandDialog.cpp
\brief show list of pending commands
\author Hugo Pereira
\version $Revision: 1.1 $
\date $Date: 2012/01/20 08:16:59 $
*/

#include "AlienCommandDialog.h"

#include "ColumnSelectionMenu.h"
#include "Icons.h"
#include "IconEngine.h"
#include "IconSize.h"
#include "AlienCommandModel.h"
#include "TreeView.h"

#include <QtGui/QHeaderView>
#include <QtGui/QShortcut>

//__________________________________________________
AlienCommandDialog::AlienCommandDialog( QWidget* parent ):
    CustomDialog( parent, CloseButton )
{

    Debug::Throw( "AlienCommandDialog::AlienCommandDialog.\n" );
    setWindowTitle( "Command List - gridwatch" );

    // customize layout
    layout()->setMargin(0);
    layout()->setSpacing(0);
    buttonLayout().setMargin(5);

    setAttribute( Qt::WA_DeleteOnClose );
    setOptionName( "JOB_COMMAND_DIALOG" );
    mainLayout().addWidget( list_ = new TreeView(this) );

    list().setSortingEnabled( false );
    list().header()->hide();
    list().setIconSize( IconSize( IconSize::Medium ) );
    list().setSelectionMode( TreeView::ContiguousSelection );

    // abort action
    addAction( abortAction_ = new QAction( IconEngine::get( ICONS::KILL ), "&Abort", this ) );
    connect( abortAction_, SIGNAL( triggered( void ) ), SLOT( _abortCommands( void ) ) );
    abortAction_->setEnabled( false );

    list().menu().addAction( abortAction_ );
    list().menu().addMenu( new ColumnSelectionMenu( &list().menu(), &list() ) );

    // close accelerator
    new QShortcut( Qt::CTRL+Qt::Key_W, this, SLOT( close() ) );

}

//__________________________________________________
void AlienCommandDialog::setModel( QAbstractItemModel* model )
{
    list().setModel( model );
    connect( list().selectionModel(), SIGNAL( selectionChanged ( const QItemSelection &, const QItemSelection & ) ), SLOT( _updateActions() ) );
}

//__________________________________________________
void AlienCommandDialog::_updateActions( void )
{ abortAction_->setEnabled( !list().selectionModel()->selectedIndexes().isEmpty() ); }

//__________________________________________________
void AlienCommandDialog::_abortCommands( void )
{
    Debug::Throw( "AlienCommandDialog::_abortCommands.\n" );

    // check selection model
    if( !list().selectionModel() ) return;

    // emit abortCommand signals
    QModelIndexList selectedIndexes( list().selectionModel()->selectedIndexes() );
    for( QModelIndexList::iterator iter = selectedIndexes.begin(); iter != selectedIndexes.end(); ++iter )
    { emit commandAborted( static_cast<AlienCommandModel*>(list().model())->get( *iter ) ); }

    // clear selection
    list().selectionModel()->clear();

}
