// $Id: AlienCommandList.cpp,v 1.1 2012/01/20 08:16:59 hpereira Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* software; if not, write to the Free Software Foundation, Inc., 59 Temple
* Place, Suite 330, Boston, MA  02111-1307 USA
*
*
*******************************************************************************/

#include "AlienCommandList.h"

#include <cassert>
#include <algorithm>

//__________________________________________________________________
bool AlienCommandList::empty( void ) const
{ return std::find_if( list_.begin(), list_.end(), NonEmptyFTor() ) == list_.end(); }

//__________________________________________________________________
const AlienCommand& AlienCommandList::front( void ) const
{ return front_; }

//__________________________________________________________________
bool AlienCommandList::append( const AlienCommand& command )
{
    Debug::Throw( "AlienCommandList::append.\n" );
    if( set_.find( command ) != set_.end() ) return false;
    set_.insert( command );

    const bool empty( this->empty() );

    // find list matching command priority
    if( command.priority() >= list_.size() )
    { list_.resize( command.priority()+1 ); }

    // append
    list_[command.priority()].push_back( command );

    // store
    if( empty ) front_ = command;

    return true;

}

//__________________________________________________________________
bool AlienCommandList::popFront( void )
{
    Debug::Throw( "AlienCommandList::popFront.\n" );
    set_.erase( front_ );
    assert( list_.size() > front_.priority() );
    assert( !list_[front_.priority()].empty() );
    assert( list_[front_.priority()].front() == front_ );
    list_[front_.priority()].pop_front();

    // advance to next
    PriorityList::const_iterator iter( std::find_if( list_.begin(), list_.end(), NonEmptyFTor() ) );
    if( iter != list_.end() ) front_ = iter->front();

    return true;
}

//__________________________________________________________________
bool AlienCommandList::abort( const AlienCommand& command )
{
    Debug::Throw( "AlienCommandList::abort.\n" );
    if( command == front_ || set_.find( command ) == set_.end() ) return false;

    // remove from set
    set_.erase( command );
    AlienCommand::List& commands( list_[command.priority()] );
    AlienCommand::List::iterator iter = std::find( commands.begin(), commands.end(), command );
    assert( iter != commands.end() );
    commands.erase( iter );
    return true;

}
