#ifndef AlienCommandList_h
#define AlienCommandList_h

// $Id: AlienCommandList.h,v 1.1 2012/01/20 08:17:00 hpereira Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* software; if not, write to the Free Software Foundation, Inc., 59 Temple
* Place, Suite 330, Boston, MA  02111-1307 USA
*
*
*******************************************************************************/

#include "Counter.h"
#include "AlienCommand.h"

#include <vector>

class AlienCommandList: public Counter
{

    public:

    //! constructor
    AlienCommandList( void ):
        Counter( "AlienCommandList" )
    {}

    //! destructor
    virtual ~AlienCommandList( void )
    {}

    //! size
    unsigned int size( void ) const
    { return set_.size(); }

    //! return true if empty
    bool empty( void ) const;

    //! true if has pending commands (beside the running one)
    bool hasPendingCommands( void )
    { return size() > 1; }

    //! return front command
    const AlienCommand& front( void ) const;

    //! append
    /*! returns true if appended */
    bool append( const AlienCommand& );

    //! pop front
    bool popFront( void );

    //! abort a given command from list. Return true if aborted
    /*! note: the "front" command is never aborted */
    bool abort( const AlienCommand& );

    private:

    typedef std::vector<AlienCommand::List> PriorityList;

    //! used to find first non empty
    class NonEmptyFTor
    {
        public:

        bool operator() (const AlienCommand::List& list )
        { return !list.empty(); }

    };

    //! list of commands
    PriorityList list_;

    //! set of commands to be kept in sync
    AlienCommand::Set set_;

    //! front command
    AlienCommand front_;

};

#endif
