#ifndef AlienCommandModel_h
#define AlienCommandModel_h

// $Id: AlienCommandModel.h,v 1.1 2012/01/20 08:17:00 hpereira Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* software; if not, write to the Free Software Foundation, Inc., 59 Temple
* Place, Suite 330, Boston, MA  02111-1307 USA
*
*
*******************************************************************************/

/*!
\file    AlienCommandModel.h
\brief   Stores ftp commands for display in lists
\author  Hugo Pereira
\version $Revision: 1.1 $
\date    $Date: 2012/01/20 08:17:00 $
*/

#include "Counter.h"
#include "ListModel.h"
#include "AlienCommand.h"

//! Job model. Stores job information for display in lists
class AlienCommandModel : public ListModel<AlienCommand>, public Counter
{

    //! Qt meta object declaration
    Q_OBJECT

    public:

    //! constructor
    AlienCommandModel(QObject *parent = 0);

    //! destructor
    virtual ~AlienCommandModel()
    {}

    //! number of columns
    enum { nColumns = 3 };

    //! column type enumeration
    enum ColumnType { ID, NAME, ARGUMENTS };

    //!@name methods reimplemented from base class
    //@{

    //! data
    virtual QVariant data(const QModelIndex &index, int role) const;

    //! header data
    virtual QVariant headerData(int section, Qt::Orientation orientation, int role = Qt::DisplayRole) const;

    //! number of columns for a given index
    // virtual int columnCount(const QModelIndex &parent = QModelIndex()) const
    virtual int columnCount(const QModelIndex & = QModelIndex()) const
    { return nColumns; }

    //@}

    public slots:

    //! add file
    virtual void add( AlienCommand command );

    //! remove
    virtual void remove( AlienCommand command );

    //! update configuration
    void updateConfiguration( void );

    protected:

    //! sort
    virtual void _sort( int column, Qt::SortOrder order = Qt::AscendingOrder )
    {}

    private:

    //! install pixmaps
    void _installIcons( void ) const;

    //! icon from command type
    static QIcon _icon( AlienCommand::Type );

    //! icon cache
    typedef std::map<AlienCommand::Type, QIcon> IconCache;

    static IconCache& _icons( void );

    //! list column names
    static const QString columnTitles_[nColumns];

};

#endif
