// $Id: ConfigurationDialog.cpp,v 1.22 2012/01/20 17:48:30 hpereira Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* software; if not, write to the Free Software Foundation, Inc., 59 Temple
* Place, Suite 330, Boston, MA  02111-1307 USA
*
*
*******************************************************************************/

#include "ConfigurationDialog.h"
#include "OptionBrowsedLineEditor.h"
#include "Icons.h"
#include "IconEngine.h"
#include "OptionCheckBox.h"
#include "OptionColorDisplay.h"
#include "OptionSpinBox.h"
#include "GridLayout.h"

#include <QtGui/QGroupBox>
#include <QtGui/QLabel>

//_________________________________________________________
ConfigurationDialog::ConfigurationDialog( QWidget* parent ):
    BaseConfigurationDialog( parent )
{

    Debug::Throw( "ConfigurationDialog::ConfigurationDialog.\n" );
    setWindowTitle( "Configuration - gridwatch" );

    // base configuration
    baseConfiguration( 0 );

    QWidget* page;
    QWidget *box;
    GridLayout* gridLayout;
    OptionColorDisplay *display;

    // commands
    page = &addPage( IconEngine::get( ICONS::PREFERENCE_FILE_TYPES ), "Applications", "Third-party applications" );
    box = new QGroupBox( page );
    page->layout()->addWidget( box );

    gridLayout = new GridLayout();
    gridLayout->setSpacing(5);
    gridLayout->setMargin(5);
    gridLayout->setMaxCount(2);
    gridLayout->setColumnAlignment( 0, Qt::AlignRight|Qt::AlignVCenter );
    box->setLayout( gridLayout );

    OptionBrowsedLineEditor* editor;
    gridLayout->addWidget( new QLabel( "alien_cp: ", box ) );
    gridLayout->addWidget( editor = new OptionBrowsedLineEditor( box, "ALIEN_CP" ) );
    addOptionWidget( editor );

    gridLayout->addWidget( new QLabel( "alien_ps: ", box ) );
    gridLayout->addWidget( editor = new OptionBrowsedLineEditor( box, "ALIEN_PS" ) );
    addOptionWidget( editor );

    gridLayout->addWidget( new QLabel( "alien_who: ", box ) );
    gridLayout->addWidget( editor = new OptionBrowsedLineEditor( box, "ALIEN_WHO" ) );
    addOptionWidget( editor );

    gridLayout->addWidget( new QLabel( "alien_who: ", box ) );
    gridLayout->addWidget( editor = new OptionBrowsedLineEditor( box, "ALIEN_WHOAMI" ) );
    addOptionWidget( editor );

    gridLayout->addWidget( new QLabel( "alien_resubmit: ", box ) );
    gridLayout->addWidget( editor = new OptionBrowsedLineEditor( box, "ALIEN_RESUBMIT" ) );
    addOptionWidget( editor );

    gridLayout->addWidget( new QLabel( "alien_kill: ", box ) );
    gridLayout->addWidget( editor = new OptionBrowsedLineEditor( box, "ALIEN_KILL" ) );
    addOptionWidget( editor );

    gridLayout->addWidget( new QLabel( "gbbox: ", box ) );
    gridLayout->addWidget( editor = new OptionBrowsedLineEditor( box, "GBBOX" ) );
    addOptionWidget( editor );

    box = new QGroupBox( "Environment", page );
    page->layout()->addWidget( box );
    gridLayout = new GridLayout();
    gridLayout->setSpacing(5);
    gridLayout->setMargin(5);
    gridLayout->setMaxCount(2);
    gridLayout->setColumnAlignment( 0, Qt::AlignRight|Qt::AlignVCenter );
    box->setLayout( gridLayout );

    gridLayout->addWidget( new QLabel( "certificates: ", box ) );
    gridLayout->addWidget( editor = new OptionBrowsedLineEditor( box, "CERTIFICATES_PATH" ) );
    editor->setFileMode( QFileDialog::Directory );
    addOptionWidget( editor );

    // appearance
    page = &addPage( IconEngine::get( ICONS::PREFERENCE_APPEARANCE ), "Appearance", "Application appearance" );

    // running job color
    box = new QGroupBox( "Job State Colors", page );
    page->layout()->addWidget( box );

    gridLayout = new GridLayout();
    gridLayout->setSpacing(5);
    gridLayout->setMargin(5);
    gridLayout->setMaxCount(2);
    gridLayout->setColumnAlignment( 0, Qt::AlignRight|Qt::AlignVCenter );
    box->setLayout( gridLayout );

    gridLayout->addWidget( new QLabel( "Running jobs: ", box ) );
    display = new OptionColorDisplay( box, "RUNNING_JOB_COLOR" );
    addOptionWidget( display );
    gridLayout->addWidget( display );

    gridLayout->addWidget( new QLabel( "Failed jobs: ", box ) );
    display = new OptionColorDisplay( box, "FAILED_JOB_COLOR" );
    addOptionWidget( display );
    gridLayout->addWidget( display );

    gridLayout->addWidget( new QLabel( "Completed jobs: ", box ) );
    display = new OptionColorDisplay( box, "COMPLETED_JOB_COLOR" );
    addOptionWidget( display );
    gridLayout->addWidget( display );

    // Job log colors
    box = new QGroupBox( "Log Colors", page );
    page->layout()->addWidget( box );

    gridLayout = new GridLayout();
    gridLayout->setSpacing(5);
    gridLayout->setMargin(5);
    gridLayout->setMaxCount(2);
    gridLayout->setColumnAlignment( 0, Qt::AlignRight|Qt::AlignVCenter );
    box->setLayout( gridLayout );

    gridLayout->addWidget( new QLabel( "Trace information: ", box ) );
    display = new OptionColorDisplay( box, "JOB_TRACE_TRACE_COLOR" );
    addOptionWidget( display );
    gridLayout->addWidget( display );

    gridLayout->addWidget( new QLabel( "State information: ", box ) );
    display = new OptionColorDisplay( box, "JOB_TRACE_STATE_COLOR" );
    addOptionWidget( display );
    gridLayout->addWidget( display );

    gridLayout->addWidget( new QLabel( "Process information: ", box ) );
    display = new OptionColorDisplay( box, "JOB_TRACE_PROC_COLOR" );
    addOptionWidget( display );
    gridLayout->addWidget( display );

    gridLayout->addWidget( new QLabel( "Submission information: ", box ) );
    display = new OptionColorDisplay( box, "JOB_TRACE_SUBMIT_COLOR" );
    addOptionWidget( display );
    gridLayout->addWidget( display );

    // unsorted
    page = &addPage( IconEngine::get( ICONS::PREFERENCE_UNSORTED ), "Unsorted", "Additional unsorted settings" );

    box = new QWidget( page );
    page->layout()->addWidget( box );

    QVBoxLayout* layout = new QVBoxLayout();
    layout->setMargin(0);
    layout->setSpacing(5);
    box->setLayout( layout );

    QHBoxLayout* hLayout = new QHBoxLayout();
    hLayout->setSpacing(5);
    hLayout->setMargin(0);
    layout->addLayout( hLayout );

    gridLayout = new GridLayout();
    gridLayout->setSpacing(5);
    gridLayout->setMargin(5);
    gridLayout->setMaxCount(2);
    gridLayout->setColumnAlignment( 0, Qt::AlignRight|Qt::AlignVCenter );
    hLayout->addLayout( gridLayout );

    // max traced jobs
    gridLayout->addWidget( new QLabel( "Max number of traced jobs: ", box ) );
    OptionSpinBox *spinbox = new OptionSpinBox( box, "MAX_TRACED_JOBS" );
    spinbox->setMinimum( 0 );
    spinbox->setMaximum( 200 );
    addOptionWidget( spinbox );

    gridLayout->addWidget( spinbox );

    // refresh
    gridLayout->addWidget( new QLabel( "Refresh (seconds): ", box ) );
    spinbox = new OptionSpinBox( box, "REFRESH_RATE" );
    spinbox->setMinimum( 1 );
    spinbox->setMaximum( 60 );
    addOptionWidget( spinbox );

    spinbox->setToolTip( "Time interval (seconds) between two refresh" );
    gridLayout->addWidget( spinbox );

    hLayout->addStretch( 1 );

    OptionCheckBox* checkbox;
    layout->addWidget( checkbox = new OptionCheckBox( "Enable command log", box, "LOG_ENABLED" ) );
    addOptionWidget( checkbox );

    layout->addWidget( checkbox = new OptionCheckBox( "Hide killed jobs", box, "HIDE_KILLED_JOBS" ) );
    addOptionWidget( checkbox );

    // load initial configuration
    _read();

}
