// $Id: JobCollection.cpp,v 1.3 2011/11/10 23:06:18 hpereira Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* software; if not, write to the Free Software Foundation, Inc., 59 Temple
* Place, Suite 330, Boston, MA  02111-1307 USA
*
*******************************************************************************/

#include "JobCollection.h"
#include "XmlDef.h"
#include "XmlError.h"

#include <QtXml/QDomDocument>
#include <QtXml/QDomElement>

//________________________________________________________
bool JobCollection::read( const File& file )
{

    // parse the file
    QFile in( file );
    if( !in.open( QIODevice::ReadOnly ) )
    {
        Debug::Throw(0) << "JobCollection::read - cannot open file " << file << endl;
        return false;
    }

    // create document
    QDomDocument document;
    XmlError error;
    if ( !document.setContent( &in, &error.error(), &error.line(), &error.column() ) )
    {
        in.close();
        return false;
    }

    // read first child
    QDomElement docElement = document.documentElement();
    QString tagName( docElement.tagName() );
    if( tagName != XML::REALM )
    {
        Debug::Throw(0) << "JobCollection::read - invalid tag name: " << tagName << endl;
        return false;
    }

    // parse children
    for(QDomNode node = docElement.firstChild(); !node.isNull(); node = node.nextSibling() )
    {
        QDomElement element = node.toElement();
        if( element.isNull() ) continue;

        QString tagName( element.tagName() );

        // children
        if( tagName == XML::JOB_SET ) add( JobSet( element ) );
        else Debug::Throw(0) << "JobCollection::read - unrecognized tagName: " << tagName << endl;
    }

    return true;

}

//________________________________________________________
bool JobCollection::write( const File& file ) const
{

    // check history file
    QFile out( file );
    if( !out.open( QIODevice::WriteOnly ) )
    {
        Debug::Throw(0) << "JobCollection::write - ERROR: Can't open file \"" << file << "\".\n";
        return false;
    }

    // create document
    QDomDocument document;
    QDomElement top( document.appendChild( document.createElement( XML::REALM ) ).toElement() );

    // add job sets
    for( List::const_iterator iter = jobSets_.begin(); iter != jobSets_.end(); ++iter )
    { top.appendChild( iter->domElement( document )  ); }

    // write dom document and close
    out.write( document.toByteArray() );
    out.close();

    return true;

}
