#ifndef JobManager_h
#define JobManager_h
// $Id: JobManager.h,v 1.16 2012/01/20 17:01:36 hpereira Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* software; if not, write to the Free Software Foundation, Inc., 59 Temple
* Place, Suite 330, Boston, MA  02111-1307 USA
*
*
*******************************************************************************/

/*!
\file    JobManager.h
\brief   Job managment singleton
\author  Hugo Pereira
\version $Revision: 1.16 $
\date    $Date: 2012/01/20 17:01:36 $
*/


#include "AlienCommand.h"
#include "JobModel.h"
#include "JobSet.h"
#include "TimeStamp.h"

#include <QtGui/QWidget>
#include <set>

class TreeView;

/*!
\class JobManager
\brief Job managment singleton
*/
class JobManager:public QWidget
{

    //! Qt meta object declaration
    Q_OBJECT

    public:

    //! constructor
    JobManager( QWidget* );

    //! destructor
    virtual ~JobManager( void );

    //! list
    TreeView& list( void ) const
    { return *list_; }

    //! process job list
    /*! return the list of "incomplete" jobs, for which a trace command is needed */
    JobSet updateJobList( JobSet );

    //! update specific job
    void updateJob( const Job& );

    //! update job children
    void updateJobChildren( const Job&, const Job::IdSet& );

    //! retrieve selected jobs
    JobSet selectedJobs( bool = false );

    //! user
    QString user( void ) const
    { return user_; }

    //! update user
    bool setUser( QString );

    //! model
    const JobModel& model( void ) const
    { return model_; }

    signals:

    //! busy signal
    void busy( int );

    //! progress
    void progressAvailable( int );

    //! idle
    void idle( void );

    //! message
    void messageAvailable( const QString& );

    private slots:

    //! store selected jobs in model
    void _storeSelectedJobs( void );

    //! restore selected jobs from model
    void _restoreSelectedJobs( void );

    //! store expanded jobs in model
    void _storeExpandedJobs( void );

    //! restore expanded jobs from model
    void _restoreExpandedJobs( void );

    private:

    //! display list
    TreeView* list_;

    //! current user
    QString user_;

    //! job model
    JobModel model_;

};

#endif
