#ifndef JobStatistics_h
#define JobStatistics_h

// $Id: JobStatistics.h,v 1.6 2011/11/02 14:06:10 hpereira Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* software; if not, write to the Free Software Foundation, Inc., 59 Temple
* Place, Suite 330, Boston, MA  02111-1307 USA
*
*******************************************************************************/

/*!
\file JobStatistics.h
\brief job statistics container
\author Hugo Pereira
\version $Revision: 1.6 $
\date $Date: 2011/11/02 14:06:10 $
*/

#include "Counter.h"
#include "Debug.h"
#include "TimeStamp.h"

#include <QtCore/QString>
#include <cassert>
#include <vector>

class JobSet;

//! job statistics container
class JobStatistics: public Counter
{
    public:

    //! number of data fields
    enum { nFields = 6 };

    //! allows fast, keyed access to any data field
    enum FieldType
    {
        TOTAL,
        COMPLETED,
        RUNNING,
        PENDING,
        FAILED,
        UNKNOWN
    };

    //! initialize field names
    static void installFields( void );

    //! get field name
    static const QString& fieldName( const unsigned int& index )
    {
        assert( index <= _fieldNames().size() );
        return _fieldNames()[index];
    }

    //! constructor
    JobStatistics( const QString& user = QString() );

    //! constructor from Job list
    JobStatistics( const JobSet& );

    //! equal to operator
    bool operator == (const JobStatistics& stat ) const;

    //! equal to operator
    bool operator != (const JobStatistics& stat ) const
    { return !( *this == stat ); }

    //!@name accessors
    //@{

    const QString& user( void ) const { return user_; }
    const TimeStamp& time( void ) const { return time_; }
    int get( int type ) const
    {
        assert( type >= 0 && type < nFields );
        return fields_[type];
    }

    //@}

    //!@name modifiers
    //@{
    void setUser( const QString& value ) { user_ = value; }
    void setTime( const TimeStamp& value ) { time_ = value; }
    void set( FieldType type, int value )
    {
        assert( int(type) >= 0 && int(type) < nFields );
        fields_[type] = value;
    }
    //@}

    protected:

    //! fields
    typedef std::vector<QString> FieldNameVector;

    //! field names
    static FieldNameVector& _fieldNames( void );

    //! set xml_field name for given index
    static void _setFieldName( FieldType index, const QString& value )
    { _fieldNames()[index] = value; }

    private:

    //! time stamp
    TimeStamp time_;

    //! fields
    typedef std::vector<int> FieldVector;

    //! fields
    FieldVector fields_;

    //! user
    QString user_;

};

#endif
