// $Id: Menu.cpp,v 1.15 2012/01/20 17:48:30 hpereira Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* software; if not, write to the Free Software Foundation, Inc., 59 Temple
* Place, Suite 330, Boston, MA  02111-1307 USA
*
*
*******************************************************************************/

/*!
\file Menu.cc
\brief main menu
\author Hugo Pereira
\version $Revision: 1.15 $
\date $Date: 2012/01/20 17:48:30 $
*/

#include "Debug.h"
#include "DebugMenu.h"
#include "Application.h"
#include "Icons.h"
#include "IconEngine.h"
#include "JobInformationDialog.h"
#include "Menu.h"
#include "MainWindow.h"
#include "Singleton.h"
#include "XmlOptions.h"

#include <QtGui/QMenu>

//__________________________________________________
Menu::Menu( QWidget* parent ):
    QMenuBar( parent ),
    Counter( "Menu" )
{

    Debug::Throw( "Menu::Menu\n" );

    // generic menu
    QMenu *menu;

    // application and top widget
    Application& application( *static_cast<Application*>(Singleton::get().application()) );
    MainWindow& mainWindow( *static_cast<MainWindow*>(topLevelWidget()) );

    // file menu
    menu = addMenu( "File" );
    menu->addAction( &mainWindow.addFrameAction() );
    menu->addAction( &mainWindow.removeFrameAction() );
    menu->addAction( &mainWindow.updateAction() );
    menu->addAction( &mainWindow.clearAction() );
    menu->addSeparator();
    menu->addAction( &application.closeAction() );

    // windows menu
    windowsMenu_ = addMenu( "Windows" );
    connect( windowsMenu_, SIGNAL( aboutToShow() ), this, SLOT( _updateWindowsMenu() ) );

    // tools
    menu = addMenu( "Tools" );
    menu->addAction( &mainWindow.defaultUserAction() );
    menu->addAction( &mainWindow.userListAction() );

    // Settings menu
    menu = addMenu( "Settings" );
    menu->addAction( &application.toggleLogAction() );
    menu->addAction( &application.hideKilledJobsAction() );
    menu->addSeparator();
    menu->addAction( &mainWindow.toggleSummaryAction() );
    mainWindow.installToolBarsActions( *menu );
    menu->addSeparator();
    menu->addAction( &application.configurationAction() );

    // create help menu
    menu = addMenu( "Help" );
    menu->addAction( &application.aboutQtAction() );
    menu->addAction( &application.aboutAction() );

    // debug menu
    #ifdef DEBUG
    menu->addSeparator();
    DebugMenu *debug_menu( new DebugMenu( this ) );
    debug_menu->setTitle( "Debug" );
    menu->addMenu( debug_menu );
    #endif

}

//____________________________________________________________________
void Menu::_updateWindowsMenu( void )
{

    Debug::Throw( "Menu::_updateWindowsMenu.\n" );

    // clear menu
    windowsMenu_->clear();

    // standard actions
    Application& application( *static_cast<Application*>(Singleton::get().application()) );
    windowsMenu_->addAction( &application.commandListAction() );
    windowsMenu_->addAction( &application.logAction() );
    windowsMenu_->addSeparator();


    // get job information dialogs
    BASE::KeySet<JobInformationDialog> dialogs( &application );

    QAction* action;
    for( BASE::KeySet<JobInformationDialog>::iterator iter = dialogs.begin(); iter != dialogs.end(); ++iter )
    {
        QString buffer;
        QTextStream( &buffer ) << "Job " << (*iter)->job().id();
        windowsMenu_->addAction( action = new QAction( buffer, windowsMenu_ ) );
        connect( action, SIGNAL( triggered() ), *iter, SLOT( uniconify() ) );
    }

    if( !dialogs.empty() ) windowsMenu_->addSeparator();


    // close job dialogs
    windowsMenu_->addAction( action = new QAction( IconEngine::get( ICONS::DIALOG_CLOSE ), "&Close Job Dialogs", windowsMenu_ ) );
    connect( action, SIGNAL( triggered() ), &application, SLOT( closeJobInformationDialogs() ) );
    action->setEnabled( !dialogs.empty() );

    return;

}
