
// $Id: OpenFileDialog.cpp,v 1.3 2012/01/18 10:21:24 hpereira Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* software; if not, write to the Free Software Foundation, Inc., 59 Temple
* Place, Suite 330, Boston, MA  02111-1307 USA
*
*
*******************************************************************************/

#include "OpenFileDialog.h"
#include "CustomComboBox.h"
#include "Debug.h"
#include "FileDialog.h"
#include "IconEngine.h"
#include "Icons.h"

#include <QtGui/QGridLayout>
#include <QtGui/QButtonGroup>
#include <QtGui/QToolButton>
#include <QtGui/QLabel>

//___________________________________________________________________________
OpenFileDialog::OpenFileDialog( QWidget* parent, unsigned int mode ):
    CustomDialog( parent, OkButton|CancelButton|Separator )
{

    Debug::Throw( "OpenFileDialog::OpenFileDialog.\n" );
    setOptionName( "OPEN_FILE_DIALOG" );

    mainLayout().addWidget( new QLabel( "Which action would you like to perform ?", this ) );

    QGridLayout* gridLayout = new QGridLayout();
    gridLayout->setMargin(0);
    mainLayout().addLayout( gridLayout );

    gridLayout->addWidget( openWithRadioButton_ = new QRadioButton( "Open with", this ), 0, 0, 1, 1 );
    gridLayout->addWidget( actionComboBox_ = new CustomComboBox( this ), 0, 1, 1, 1 );
    actionComboBox_->setEditable( true );
    actionComboBox_->setAutoCompletion( true );

    QToolButton* button;
    gridLayout->addWidget( button = new QToolButton( this ), 0, 2, 1, 1 );
    button->setIcon( IconEngine::get( ICONS::OPEN ) );
    button->setAutoRaise( true );
    connect( button, SIGNAL( clicked() ), SLOT( _browse() ) );

    gridLayout->addWidget( saveAsRadioButton_ = new QRadioButton( "Save File", this ), 1, 0, 1, 3 );
    gridLayout->setColumnStretch( 1, 1 );

    QButtonGroup* buttonGroup = new QButtonGroup( this );
    buttonGroup->addButton( openWithRadioButton_ );
    buttonGroup->addButton( saveAsRadioButton_ );

    connect( openWithRadioButton_, SIGNAL( toggled( bool ) ), actionComboBox_, SLOT( setEnabled( bool ) ) );
    connect( openWithRadioButton_, SIGNAL( toggled( bool ) ), button, SLOT( setEnabled( bool ) ) );

    openWithRadioButton_->setEnabled( mode & OpenWith );
    saveAsRadioButton_->setEnabled( mode & SaveAs );

    if( mode & SaveAs )
    {

        saveAsRadioButton_->setChecked( true );
        actionComboBox_->setEnabled( false );
        button->setEnabled( false );

    } else {

        openWithRadioButton_->setChecked( true );

    }

}

//______________________________________________________________________
void OpenFileDialog::_browse( void )
{
    Debug::Throw( "OpenFileDialog::_browse.\n" );

    // create file dialog
    QString file( FileDialog( this ).getFile() );
    if( !file.isNull() ) actionComboBox().setEditText( file );
    return;
}
