#ifndef UserSet_h
#define UserSet_h

// $Id: UserSet.h,v 1.3 2011/11/19 10:58:23 hpereira Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* software; if not, write to the Free Software Foundation, Inc., 59 Temple
* Place, Suite 330, Boston, MA  02111-1307 USA
*
*
*******************************************************************************/

/*!
\file    UserSet.h
\brief   User list
\author  Hugo Pereira
\version $Revision: 1.3 $
\date    $Date: 2011/11/19 10:58:23 $
*/


#include <QString>

#include <set>
#include "Counter.h"

//! user priority class
class UserSet: public std::set<QString>, public Counter
{
    public:

    //! constructor
    UserSet( std::set<QString> users = std::set<QString>() ):
        std::set<QString>( users ),
        Counter( "UserSet" )
    { insert( defaultUser() ); }

    //! remove/add default user
    void setNeedsDefault( bool value )
    {
        if( value ) insert( defaultUser() );
        else erase( defaultUser() );
    }

    //! true if given user is "all"
    static bool isDefaultUser( const QString& value )
    { return value == DEFAULT_USER; }

    //! all users string
    static const QString& defaultUser( void )
    { return DEFAULT_USER; }

    private:

    //! default user
    static const QString DEFAULT_USER;

};

#endif
